package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.TPlanInfo;
import org.apache.ibatis.annotations.Param;

/**
 * 应急预案Mapper接口
 * 
 * @author zehong
 * @date 2022-02-11
 */
public interface TPlanInfoMapper 
{
    /**
     * 查询应急预案
     * 
     * @param planId 应急预案ID
     * @return 应急预案
     */
    public TPlanInfo selectTPlanInfoById(Long planId);

    /**
     * 查询应急预案列表
     * 
     * @param tPlanInfo 应急预案
     * @return 应急预案集合
     */
    public List<TPlanInfo> selectTPlanInfoList(TPlanInfo tPlanInfo);

    /**
     * 新增应急预案
     * 
     * @param tPlanInfo 应急预案
     * @return 结果
     */
    public int insertTPlanInfo(TPlanInfo tPlanInfo);

    /**
     * 修改应急预案
     * 
     * @param tPlanInfo 应急预案
     * @return 结果
     */
    public int updateTPlanInfo(TPlanInfo tPlanInfo);

    /**
     * 删除应急预案
     * 
     * @param planId 应急预案ID
     * @return 结果
     */
    public int deleteTPlanInfoById(Long planId);

    /**
     * 批量删除应急预案
     * 
     * @param planIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPlanInfoByIds(Long[] planIds);

    /**
     * 公司列表
     */
    public List<Map<String,Object>> selectEnterprise();

    /**
     * 公司列表 - 转办时使用 - 排除了一些之前派发的公司
     * @return
     */
    public List<Map<String,Object>> transferEnterpriseList(@Param(value = "excludeEnterpriseIdList") List<String> excludeEnterpriseIdList);
}
